@@ -27,23 +27,21 @@ The parser which will be used. This is instantiated and defaults to L<Text::Mark
 
 =cut
 
-has markdown_parser =>
+has markdown_parser => (
   is      => 'rw',
   lazy    => 1,
   default => sub {
-    'Text::Markdown'
+    'Text::Markdown';
   },
-  coerce  => sub {
-    instantiate( $_[0] )
-  }
-;
+  coerce => sub {
+    instantiate( $_[0] );
+  },
+);
 
 sub augment {
   my $self = shift;
   my $item = shift;
-  $item->content (
-    $self->markdown_parser->markdown($item->content)
-  );
+  $item->content( $self->markdown_parser->markdown( $item->content ) );
   return $item;
 }
 
