@@ -4,7 +4,6 @@ use warnings;
 
 use Moo;
 
-
 use Digest::SHA;
 use Time::HiRes; # overrides time()
 
@@ -28,18 +27,19 @@ Accepts and returns the credentials if the C<password> matches the C<user_id>. A
 
 has extra_salt => (
   is      => 'rw',
-  default =>  "If you haven't already, try powdered vegetable bouillon"
+  default => "If you haven't already, try powdered vegetable bouillon"
 );
 
 sub authenticate {
   my $self        = shift;
   my $credentials = shift;
-  my $user_id     = $credentials->fields->{user_id}  // return;
+  my $user_id     = $credentials->fields->{user_id} // return;
   my $password    = $credentials->fields->{password} // return;
 
-  if ( $self->verify_password ( $user_id, $password ) ) {
+  if ( $self->verify_password( $user_id, $password ) ) {
     return $credentials->accept('Passwords match');
   }
+
   # if we ever need to know if the user does not exist, now is the time to ask,
   # but we do not externally expose the difference between
   # "user not found" and "password doesn't match"
@@ -48,15 +48,16 @@ sub authenticate {
 
 sub _password_salt_and_hash {
   my $self = shift;
-  return Digest::SHA::sha512_base64 (
+  return Digest::SHA::sha512_base64(
     $_[0] . $_[1] #:5.10 doesn't like shift . shift
   );
 }
 
 sub _generate_salt {
+
   # pseudorandom salt
   my $self = shift;
-  return Digest::SHA::sha512_base64 (
+  return Digest::SHA::sha512_base64(
     time . (
       $self->extra_salt # don't allow the admin not to set a salt:
     )
@@ -73,21 +74,18 @@ Returns the result of C<eq>.
 
 =cut
 
-
 sub verify_password {
-  my ($self, $user_id, $plaintext_password) = @_;
+  my ( $self, $user_id, $plaintext_password ) = @_;
 
-  my $user_meta               = $self->storage->get_meta ("/users/$user_id");
+  my $user_meta               = $self->storage->get_meta("/users/$user_id");
   my $real_encrypted_password = $user_meta->{encrypted_password};
   my $salt                    = $user_meta->{salt};
 
-  return undef unless defined $real_encrypted_password and defined $plaintext_password;
+  return undef
+    unless defined $real_encrypted_password and defined $plaintext_password;
 
-  return (
-    $real_encrypted_password
-  eq
-    $self->_password_salt_and_hash ($plaintext_password, $salt)
-  );
+  return ( $real_encrypted_password eq
+      $self->_password_salt_and_hash( $plaintext_password, $salt ) );
 }
 
 =head3 set_password
@@ -103,13 +101,18 @@ Amends the C<encrypted_password> and C<salt> fields of the user's meta.
 # note: currently this implicitly creates a user. Should set/patch create new content, or just edit it?
 # maybe a create verb - but is is this going to be compatible with kvp stores? How will this work when you have content and meta and settings all to be created?
 sub set_password {
-  my ($self, $user_id, $plaintext_password) = @_;
-  return undef unless $plaintext_password; # as empty passwords will only cause trouble.
+  my ( $self, $user_id, $plaintext_password ) = @_;
+  return undef
+    unless $plaintext_password; # as empty passwords will only cause trouble.
   my $new_salt = $self->_generate_salt;
-  $self->storage->patch_meta ( "/user/$user_id", {
-    encrypted_password => $self->_password_salt_and_hash ($plaintext_password, $new_salt),
-    salt               => $new_salt
-  } );
+  $self->storage->patch_meta(
+    "/user/$user_id",
+    {
+      encrypted_password =>
+        $self->_password_salt_and_hash( $plaintext_password, $new_salt ),
+      salt => $new_salt
+    }
+  );
 }
 
 =head3 create_user
