@@ -16,41 +16,43 @@ Articulate::Authorisation
 
 =head1 CONFIGURATION
 
-  plugins:
-    Articulate::Authorisation:
-      rules:
-      - Articulate::Authorisation::OwnerOverride
-      - Articulate::Authorisation::AlwaysAllow
+  components:
+    authorisation:
+      Articulate::Authorisation:
+        rules:
+          - Articulate::Authorisation::OwnerOverride
+          - Articulate::Authorisation::AlwaysAllow
 
 
 =cut
 
-has rules =>
+has rules => (
   is      => 'rw',
   default => sub { [] },
-  coerce  => sub { instantiate_array(@_) };
+  coerce  => sub { instantiate_array(@_) }
+);
 
 =head3 permitted
 
   $self->permitted( $user_id, $permission, $location );
 
-Asks each of the rules in turn whether the user has the specified permission for that location.
+Asks each of the rules in turn whether the user has the specified
+permission for that location.
 
-If so, returns the role under which they have that permission. Otherwise, returns undef. (Each provider should do likewise)
+If so, returns the role under which they have that permission.
+Otherwise, returns undef. (Each provider should do likewise)
 
 =cut
 
 sub permitted {
-  my $self       = shift;
-  my $user_id    = shift;
-  my $verb       = shift;
-  my $location   = shift;
-  my $p = permission ($user_id, $verb, $location);
+  my $self     = shift;
+  my $user_id  = shift;
+  my $verb     = shift;
+  my $location = shift;
+  my $p        = permission( $user_id, $verb, $location );
   foreach my $rule ( @{ $self->rules } ) {
     my $authed_role;
-    if (
-      $rule->permitted( $p )
-    ) {
+    if ( $rule->permitted($p) ) {
       return $p;
     }
     elsif ( $p->denied ) {
@@ -72,5 +74,4 @@ sub permitted {
 
 =cut
 
-
 1;
