@@ -12,11 +12,10 @@ has verbs => (
     my $self = shift;
     return {
       map { m/^(handle_(.*))$/; $2 => $1; }
-      grep { /^handle_/ }
-      @{ Class::Inspector->methods(ref $self) },
+      grep { /^handle_/ } @{ Class::Inspector->methods( ref $self ) },
     };
   },
-  coerce  => sub {
+  coerce => sub {
     my $original = shift;
     if ( ref $original eq ref {} ) {
       return $original;
@@ -24,7 +23,7 @@ has verbs => (
     elsif ( ref $original eq ref {} ) {
       return { map { $_ => "handle_$_"; } @$original };
     }
-    return { $original => "handle_$original" }
+    return { $original => "handle_$original" };
   },
 );
 
@@ -33,10 +32,10 @@ sub process_request {
   my $request = shift;
   my $verbs   = $self->verbs;
   my $verb    = $request->verb;
-  if ( exists $verbs->{ $verb } ) {
-    my $method = $verbs->{ $verb };
-    $request->app($self->app);
-    return $self->$method($request, @_);
+  if ( exists $verbs->{$verb} ) {
+    my $method = $verbs->{$verb};
+    $request->app( $self->app );
+    return $self->$method( $request, @_ );
   }
   return undef; # whatever else the user wants, we can't provide it
 }
