@@ -8,13 +8,10 @@ use Articulate::Syntax;
 use Moo;
 with 'Articulate::Role::Service';
 
-
 sub handle_login_form {
-  my $self     = shift;
-  my $request  = shift;
-  return response 'form/login', {
-    form => { },
-  };
+  my $self    = shift;
+  my $request = shift;
+  return response 'form/login', { form => {}, };
 }
 
 1;
